[exim-cvs] Move static files into separate staticroot direct…

Top Page
Delete this message
Reply to this message
Author: Exim Git Commits Mailing List
Date:  
To: exim-cvs
Subject: [exim-cvs] Move static files into separate staticroot directory
Gitweb: http://git.exim.org/exim-website.git/commitdiff/b0968890317ffaab0352f6278340d310aacfdc54
Commit:     b0968890317ffaab0352f6278340d310aacfdc54
Parent:     02d640e51bbff6a3f48f07fc7b8c788e990e1fda
Author:     Nigel Metheringham <nigel.metheringham@???>
AuthorDate: Thu Jun 28 12:17:55 2012 +0100
Committer:  Nigel Metheringham <nigel.metheringham@???>
CommitDate: Mon Jul 2 14:27:15 2012 +0100


    Move static files into separate staticroot directory


    This is a step on the way to making it possible to generate
    documentation for a single version without the website but
    with attached js/images
---
 script/gen.pl                                 |   93 +++++++++++++++++-------
 templates/doc/chapter.xsl                     |    4 +-
 templates/doc/index.xsl                       |    4 +-
 templates/{web => static/css}/common.css      |    0
 templates/{web => static/css}/index.css       |    0
 templates/{web => static}/doc/chapter.css     |    0
 templates/{web => static}/doc/chapter.js      |    0
 templates/{web => static}/doc/contents.png    |  Bin 2859 -> 2859 bytes
 templates/{web => static}/doc/index.css       |    0
 templates/{web => static}/doc/index.js        |    0
 templates/{web => static}/doc/minus-12x12.png |  Bin 1201 -> 1201 bytes
 templates/{web => static}/doc/plus-12x12.png  |  Bin 1252 -> 1252 bytes
 templates/{web => static/js}/common.js        |    0
 templates/web/index.xsl                       |    2 +-
 templates/wrapper.xsl                         |    6 +-
 15 files changed, 74 insertions(+), 35 deletions(-)


diff --git a/templates/doc/chapter.xsl b/templates/doc/chapter.xsl
index 06e320d..bb0a337 100644
--- a/templates/doc/chapter.xsl
+++ b/templates/doc/chapter.xsl
@@ -16,7 +16,7 @@
    <xsl:variable name="html.head.append">


       <!-- CSS -->
-         <link rel="stylesheet" type="text/css" href="{$docroot}/doc/chapter.css"/>
+         <link rel="stylesheet" type="text/css" href="{$staticroot}/doc/chapter.css"/>


       <!-- Canonical -->
          <link rel="canonical" href="{/chapter/canonical_url}"/>
@@ -25,7 +25,7 @@


    <!-- JavaScript -->
       <xsl:variable name="html.body.append">
-         <script type="text/javascript" src="{$docroot}/doc/chapter.js"/>
+         <script type="text/javascript" src="{$staticroot}/doc/chapter.js"/>
       </xsl:variable>


    <!-- Table of Contents -->
diff --git a/templates/doc/index.xsl b/templates/doc/index.xsl
index 8e08d4a..651cde7 100644
--- a/templates/doc/index.xsl
+++ b/templates/doc/index.xsl
@@ -16,7 +16,7 @@
    <xsl:variable name="html.head.append">


       <!-- CSS -->
-         <link rel="stylesheet" type="text/css" href="{$docroot}/doc/index.css"/>
+         <link rel="stylesheet" type="text/css" href="{$staticroot}/doc/index.css"/>


       <!-- Canonical -->
          <link rel="canonical" href="{/book/canonical_url}"/>
@@ -25,7 +25,7 @@


    <!-- JavaScript -->
       <xsl:variable name="html.body.append">
-         <script type="text/javascript" src="{$docroot}/doc/index.js"/>
+         <script type="text/javascript" src="{$staticroot}/doc/index.js"/>
       </xsl:variable>


    <!-- CONTENT -->
diff --git a/templates/web/common.css b/templates/static/css/common.css
similarity index 100%
rename from templates/web/common.css
rename to templates/static/css/common.css
diff --git a/templates/web/index.css b/templates/static/css/index.css
similarity index 100%
rename from templates/web/index.css
rename to templates/static/css/index.css
diff --git a/templates/web/doc/chapter.css b/templates/static/doc/chapter.css
similarity index 100%
rename from templates/web/doc/chapter.css
rename to templates/static/doc/chapter.css
diff --git a/templates/web/doc/chapter.js b/templates/static/doc/chapter.js
similarity index 100%
rename from templates/web/doc/chapter.js
rename to templates/static/doc/chapter.js
diff --git a/templates/web/doc/contents.png b/templates/static/doc/contents.png
similarity index 100%
rename from templates/web/doc/contents.png
rename to templates/static/doc/contents.png
diff --git a/templates/web/doc/index.css b/templates/static/doc/index.css
similarity index 100%
rename from templates/web/doc/index.css
rename to templates/static/doc/index.css
diff --git a/templates/web/doc/index.js b/templates/static/doc/index.js
similarity index 100%
rename from templates/web/doc/index.js
rename to templates/static/doc/index.js
diff --git a/templates/web/doc/minus-12x12.png b/templates/static/doc/minus-12x12.png
similarity index 100%
rename from templates/web/doc/minus-12x12.png
rename to templates/static/doc/minus-12x12.png
diff --git a/templates/web/doc/plus-12x12.png b/templates/static/doc/plus-12x12.png
similarity index 100%
rename from templates/web/doc/plus-12x12.png
rename to templates/static/doc/plus-12x12.png
diff --git a/templates/web/common.js b/templates/static/js/common.js
similarity index 100%
rename from templates/web/common.js
rename to templates/static/js/common.js
diff --git a/templates/web/index.xsl b/templates/web/index.xsl
index 464b442..4e91c28 100644
--- a/templates/web/index.xsl
+++ b/templates/web/index.xsl
@@ -14,7 +14,7 @@
     <xsl:variable name="html.head.append">


         <!-- CSS -->
-            <link rel="stylesheet" type="text/css" href="{$docroot}/index.css"/>
+            <link rel="stylesheet" type="text/css" href="{$staticroot}/css/index.css"/>


             <!-- Canonical -->
                         <link rel="canonical" href="http://www.exim.org/"/>
diff --git a/templates/wrapper.xsl b/templates/wrapper.xsl
index 22052f9..d9a2edf 100644
--- a/templates/wrapper.xsl
+++ b/templates/wrapper.xsl
@@ -23,10 +23,10 @@
       <xsl:template match="/">
          <html lang="en-GB">
             <head>
-               <link rel="stylesheet" type="text/css" href="{$docroot}/common.css"/>
+               <link rel="stylesheet" type="text/css" href="{$staticroot}/css/common.css"/>


                <meta name="author"      content="The Exim Project. &lt;http://www.exim.org/&gt;"/>
-               <meta name="copyright"   content="Copyright ©1995-2011 The Exim Project. All rights reserved"/>
+               <meta name="copyright"   content="Copyright ©1995-2012 The Exim Project. All rights reserved"/>
                <meta name="description" content="{$html.head.description}"/>
                <meta name="keywords"    content="{$html.head.keywords}"/>
                <meta name="robots"      content="{$html.head.robots}"/>
@@ -119,7 +119,7 @@
                    <script type="text/javascript" src="//ajax.googleapis.com/ajax/libs/jquery/1.6/jquery.min.js"></script>


                 <!-- Local JavaScript -->
-                   <script type="text/javascript" src="{$docroot}/common.js"></script>
+                   <script type="text/javascript" src="{$staticroot}/js/common.js"></script>


                    <xsl:copy-of select="$html.body.append"/>
diff --git a/script/gen.pl b/script/gen.pl
index debd301..6febf7f 100755
--- a/script/gen.pl
+++ b/script/gen.pl
@@ -20,11 +20,16 @@ my $canonical_url = 'http://www.exim.org/';
## Parse arguments
my %opt = parse_arguments();

+## setup static root location
+## TODO: for doc generation only this should be within the docs dir
+$opt{staticroot} = File::Spec->catdir( $opt{docroot}, 'static' );
+
 ## Generate the pages
 my %cache;    # General cache object
 do_doc( 'spec',   $_ ) foreach @{ $opt{spec}   || [] };
 do_doc( 'filter', $_ ) foreach @{ $opt{filter} || [] };
 do_web() if ( $opt{web} );
+do_static();    # need this for all other pages generated


 ## Add the exim-html-current symlink
 print "Symlinking exim-html-current to exim-html-$opt{latest}\n" if ( $opt{verbose} );
@@ -32,67 +37,90 @@ unlink("$opt{docroot}/exim-html-current") if ( -l "$opt{docroot}/exim-html-curre
 symlink( "exim-html-$opt{latest}", "$opt{docroot}/exim-html-current" )
     || die "symlink to $opt{docroot}/exim-html-current failed";


+# ------------------------------------------------------------------
## Generate the website files
sub do_web {

+    ## copy these templates to docroot...
+    copy_transform_files( "$opt{tmpl}/web", $opt{docroot}, 0 );
+}
+
+# ------------------------------------------------------------------
+## Generate the static file set
+sub do_static {
+
+    ## make sure I have a directory
+    mkdir( $opt{staticroot} ) or die "Unable to make staticroot: $!\n" unless ( -d $opt{staticroot} );
+
+    ## copy these templates to docroot...
+    copy_transform_files( "$opt{tmpl}/static", $opt{staticroot}, 1 );
+}
+
+# ------------------------------------------------------------------
+## Generate the website files
+sub copy_transform_files {
+    my $source = shift;
+    my $target = shift;
+    my $static = shift;
+
     ## Make sure the template web directory exists
-    die "No such directory: $opt{tmpl}/web\n" unless -d "$opt{tmpl}/web";
+    die "No such directory: $source\n" unless ( -d $source );


     ## Scan the web templates
     find(
         sub {
-            my ($path) =
-                substr( $File::Find::name, length("$opt{tmpl}/web"), length($File::Find::name) ) =~ m#^/*(.*)$#;
+            my ($path) = substr( $File::Find::name, length("$source"), length($File::Find::name) ) =~ m#^/*(.*)$#;


-            if ( -d "$opt{tmpl}/web/$path" ) {
+            if ( -d "$source/$path" ) {


-                ## Create the directory in the doc root if it doesn't exist
-                if ( !-d "$opt{docroot}/$path" ) {
-                    mkdir("$opt{docroot}/$path") or die "Unable to make $opt{docroot}/$path: $!\n";
+                ## Create the directory in the target if it doesn't exist
+                if ( !-d "$target/$path" ) {
+                    mkdir("$target/$path") or die "Unable to make $target/$path: $!\n";
                 }


             }
             else {


                 ## Build HTML from XSL files and simply copy static files which have changed
-                if ( $path =~ /(.+)\.xsl$/ ) {
-                    print "Generating  : docroot:/$1.html\n" if ( $opt{verbose} );
-                    transform( undef, "$opt{tmpl}/web/$path", "$opt{docroot}/$1.html" );
+                if ( ( !$static ) and ( $path =~ /(.+)\.xsl$/ ) ) {
+                    print "Generating  : /$1.html\n" if ( $opt{verbose} );
+                    transform( undef, "$source/$path", "$target/$1.html" );
                 }
-                elsif ( -f "$opt{tmpl}/web/$path" ) {
+                elsif ( -f "$source/$path" ) {


-                    ## Skip if the file hasn't changed (mtime based)
+                    ## Skip if the file hasn't changed (mtime/size based)
                     return
-                        if -f "$opt{docroot}/$path"
-                            && ( stat("$opt{tmpl}/web/$path") )[9] == ( stat("$opt{docroot}/$path") )[9];
+                        if (( -f "$target/$path" )
+                        and ( ( stat("$source/$path") )[9] == ( stat("$target/$path") )[9] )
+                        and ( ( stat("$source/$path") )[7] == ( stat("$target/$path") )[7] ) );


                     if ( $path =~ /(.+)\.css$/ ) {
-                        print "CSS to  : docroot:/$path\n" if ( $opt{verbose} );
-                        my $content = read_file("$opt{tmpl}/web/$path");
-                        write_file( "$opt{docroot}/$path",
-                            $opt{minify} ? CSS::Minifier::XS::minify($content) : $content );
+                        print "CSS to  : /$path\n" if ( $opt{verbose} );
+                        my $content = read_file("$source/$path");
+                        write_file( "$target/$path", $opt{minify} ? CSS::Minifier::XS::minify($content) : $content );
                     }
                     elsif ( $path =~ /(.+)\.js$/ ) {
-                        print "JS to  : docroot:/$path\n" if ( $opt{verbose} );
-                        my $content = read_file("$opt{tmpl}/web/$path");
-                        write_file( "$opt{docroot}/$path",
+                        print "JS to  : /$path\n" if ( $opt{verbose} );
+                        my $content = read_file("$source/$path");
+                        write_file( "$target/$path",
                             $opt{minify} ? JavaScript::Minifier::XS::minify($content) : $content );
                     }
                     else {
                         ## Copy
-                        print "Copying to  : docroot:/$path\n" if ( $opt{verbose} );
-                        copy( "$opt{tmpl}/web/$path", "$opt{docroot}/$path" ) or die "$path: $!";
+                        print "Copying to  : /$path\n" if ( $opt{verbose} );
+                        copy( "$source/$path", "$target/$path" ) or die "$path: $!";
                     }
                     ## Set mtime
-                    utime( time, ( stat("$opt{tmpl}/web/$path") )[9], "$opt{docroot}/$path" );
+                    utime( time, ( stat("$source/$path") )[9], "$target/$path" );
                 }
             }


         },
-        "$opt{tmpl}/web"
+        "$source"
     );
 }


+# ------------------------------------------------------------------
 ## Generate index/chapter files for a doc
 sub do_doc {
     my ( $type, $xml_path ) = @_;
@@ -187,6 +215,7 @@ sub do_doc {
     }
 }


+# ------------------------------------------------------------------
 ## Fixup xref tags
 sub xref_fixup {
     my ( $xml, $prepend_chapter ) = @_;
@@ -249,6 +278,7 @@ sub xref_fixup {
     }
 }


+# ------------------------------------------------------------------
 ## Build indexes
 sub build_indexes {
     my ( $xml, $prepend_chapter, $xref ) = @_;
@@ -322,6 +352,7 @@ sub build_indexes {
     }
 }


+# ------------------------------------------------------------------
 ## Handle the transformation
 sub transform {
     my ( $xml, $xsl_path, $out_path ) = @_;
@@ -344,8 +375,12 @@ sub transform {
     ## Generate a stylesheet from the ".xsl" XML.
     my $stylesheet = XML::LibXSLT->new()->parse_stylesheet($xsl);


+    ## work out the static root relative to the target
+    my $target_dir = ( File::Spec->splitpath($out_path) )[1];
+    my $staticroot = File::Spec->abs2rel( $opt{staticroot}, $target_dir );
+
     ## Generate a doc from the XML transformed with the XSL
-    my $doc = $stylesheet->transform($xml);
+    my $doc = $stylesheet->transform( $xml, staticroot => sprintf( "'%s'", $staticroot ) );


     ## Make the containing directory if it doesn't exist
     make_path( ( $out_path =~ /^(.+)\/.+$/ )[0], { verbose => $opt{verbose} } );
@@ -356,6 +391,7 @@ sub transform {
     close $out;
 }


+# ------------------------------------------------------------------
 ## Look in the docroot for old versions of the documentation
 sub old_docs_versions {
     if ( !exists $cache{old_docs_versions} ) {
@@ -368,6 +404,7 @@ sub old_docs_versions {
     return @{ $cache{old_docs_versions} };
 }


+# ------------------------------------------------------------------
 ## error_help
 sub error_help {
     my $msg = shift;
@@ -376,6 +413,7 @@ sub error_help {
     pod2usage( -exitval => 1, -verbose => 0 );
 }


+# ------------------------------------------------------------------
## Parse arguments
sub parse_arguments {

@@ -414,6 +452,7 @@ sub parse_arguments {
     return %opt;
 }


+# ------------------------------------------------------------------
1;

__END__
@@ -516,6 +555,6 @@ Mike produced.

=head1 COPYRIGHT

-Copyright 2010-2011 Exim Maintainers. All rights reserved.
+Copyright 2010-2012 Exim Maintainers. All rights reserved.

 =cut